==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authSession/MapAuthenticationSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.authSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationSessionEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.authSession.MapAuthenticationSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> entityFieldDelegate;
    public MapAuthenticationSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getTabId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TAB_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setTabId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TAB_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getUserSessionNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setUserSessionNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setUserSessionNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public String getClientUUID() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_UUID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientUUID(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_UUID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRedirectUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REDIRECT_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setRedirectUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REDIRECT_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAction() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setAction(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getClientScopes() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_SCOPES);
    }
    @SuppressWarnings("unchecked") @Override public void setClientScopes(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_SCOPES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRequiredActions() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setRequiredActions(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRequiredAction(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRequiredAction(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocol() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.PROTOCOL);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocol(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.PROTOCOL, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getClientNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setClientNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setClientNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeClientNote(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getAuthNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAuthNote(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> getExecutionStatuses() {
        return (java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES);
    }
    @SuppressWarnings("unchecked") @Override public void setExecutionStatuses(java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setExecutionStatus(String p0, org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES, p0, p1);
    }
}

==> keycloak-model-map-22.0.5-sources.jar: org/keycloak/models/map/authSession/MapAuthenticationSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.authSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationSessionEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.authSession.MapAuthenticationSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> entityFieldDelegate;
    public MapAuthenticationSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getTabId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TAB_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setTabId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TAB_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getUserSessionNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setUserSessionNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setUserSessionNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.USER_SESSION_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public String getClientUUID() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_UUID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientUUID(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_UUID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRedirectUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REDIRECT_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setRedirectUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REDIRECT_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAction() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setAction(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getClientScopes() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_SCOPES);
    }
    @SuppressWarnings("unchecked") @Override public void setClientScopes(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_SCOPES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRequiredActions() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setRequiredActions(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRequiredAction(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRequiredAction(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocol() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.PROTOCOL);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocol(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.PROTOCOL, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getClientNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setClientNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setClientNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeClientNote(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.CLIENT_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getAuthNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAuthNote(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.AUTH_NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> getExecutionStatuses() {
        return (java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES);
    }
    @SuppressWarnings("unchecked") @Override public void setExecutionStatuses(java.util.Map<String,org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setExecutionStatus(String p0, org.keycloak.sessions.CommonClientSessionModel.ExecutionStatus p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authSession.MapAuthenticationSessionEntityFields.EXECUTION_STATUSES, p0, p1);
    }
}
